define("vs/language/json/monaco.contribution",["require","exports","../../editor.api-i0YVFWkl"],(function(r,s,n){"use strict";class g{constructor(e,l,d){this._onDidChange=new n.Emitter,this._languageId=e,this.setDiagnosticsOptions(l),this.setModeConfiguration(d)}get onDidChange(){return this._onDidChange.event}get languageId(){return this._languageId}get modeConfiguration(){return this._modeConfiguration}get diagnosticsOptions(){return this._diagnosticsOptions}setDiagnosticsOptions(e){this._diagnosticsOptions=e||Object.create(null),this._onDidChange.fire(this)}setModeConfiguration(e){this._modeConfiguration=e||Object.create(null),this._onDidChange.fire(this)}}const u={validate:!0,allowComments:!0,schemas:[],enableSchemaRequest:!1,schemaRequest:"warning",schemaValidation:"warning",comments:"error",trailingCommas:"error"},c={documentFormattingEdits:!0,documentRangeFormattingEdits:!0,completionItems:!0,hovers:!0,documentSymbols:!0,tokens:!0,colors:!0,foldingRanges:!0,diagnostics:!0,selectionRanges:!0},o=new g("json",u,c),i=()=>a().then(t=>t.getWorker());n.languages.json={jsonDefaults:o,getWorker:i};function a(){return new Promise((t,e)=>r(["../../jsonMode-CJjR_ECa"],t,e))}n.languages.register({id:"json",extensions:[".json",".bowerrc",".jshintrc",".jscsrc",".eslintrc",".babelrc",".har"],aliases:["JSON","json"],mimetypes:["application/json"]}),n.languages.onLanguage("json",()=>{a().then(t=>t.setupMode(o))}),s.getWorker=i,s.jsonDefaults=o,Object.defineProperty(s,Symbol.toStringTag,{value:"Module"})}));
