define("vs/editor/editor.main",["exports","require","vs/nls.messages-loader!","../basic-languages/monaco.contribution","../language/css/monaco.contribution","../language/html/monaco.contribution","../language/json/monaco.contribution","../language/typescript/monaco.contribution","../editor.api-i0YVFWkl"],(function(a,n,d,w,U,j,S,h,o){"use strict";function l(t){const e=Object.create(null,{[Symbol.toStringTag]:{value:"Module"}});if(t){for(const s in t)if(s!=="default"){const i=Object.getOwnPropertyDescriptor(t,s);Object.defineProperty(e,s,i.get?i:{enumerable:!0,get:()=>t[s]})}}return e.default=t,Object.freeze(e)}const u=l(n),g=""+new URL(n.toUrl("../assets/json.worker-DghZTZS7.js"),document.baseURI).href,_=""+new URL(n.toUrl("../assets/css.worker-cO8rX8Iy.js"),document.baseURI).href,m=""+new URL(n.toUrl("../assets/html.worker-BruuIJkK.js"),document.baseURI).href,k=""+new URL(n.toUrl("../assets/ts.worker-C4E4vgbE.js"),document.baseURI).href,y=""+new URL(n.toUrl("../assets/editor.worker-DM0G1eFj.js"),document.baseURI).href,f=Object.freeze(Object.defineProperty({__proto__:null,CancellationTokenSource:o.CancellationTokenSource,Emitter:o.Emitter,KeyCode:o.KeyCode,KeyMod:o.KeyMod,MarkerSeverity:o.MarkerSeverity,MarkerTag:o.MarkerTag,Position:o.Position,Range:o.Range,Selection:o.Selection,SelectionDirection:o.SelectionDirection,Token:o.Token,Uri:o.Uri,editor:o.editor,languages:o.languages},Symbol.toStringTag,{value:"Module"}));self.MonacoEnvironment={getWorker:function(t,e){return e==="json"?new Worker(r(g)):e==="css"||e==="scss"||e==="less"?new Worker(r(_)):e==="html"||e==="handlebars"||e==="razor"?new Worker(r(m)):e==="typescript"||e==="javascript"?new Worker(r(k)):new Worker(r(y))}};function r(t){const e=new Blob([["const ttPolicy = globalThis.trustedTypes?.createPolicy('defaultWorkerFactory', { createScriptURL: value => value });","globalThis.workerttPolicy = ttPolicy;",`importScripts(ttPolicy?.createScriptURL(${JSON.stringify(t)}) ?? ${JSON.stringify(t)});`,"globalThis.postMessage({ type: 'vscode-worker-ready' });"].join("")],{type:"application/javascript"});return URL.createObjectURL(e)}const b=u.toUrl("vs/editor/editor.main.css"),c=document.createElement("link");c.rel="stylesheet",c.href=b,document.head.appendChild(c),a.m=f,Object.defineProperty(a,Symbol.toStringTag,{value:"Module"})}));
