define("vs/language/html/monaco.contribution",["require","exports","../../editor.api-i0YVFWkl"],(function(D,n,u){"use strict";class p{constructor(t,c,i){this._onDidChange=new u.Emitter,this._languageId=t,this.setOptions(c),this.setModeConfiguration(i)}get onDidChange(){return this._onDidChange.event}get languageId(){return this._languageId}get options(){return this._options}get modeConfiguration(){return this._modeConfiguration}setOptions(t){this._options=t||Object.create(null),this._onDidChange.fire(this)}setModeConfiguration(t){this._modeConfiguration=t||Object.create(null),this._onDidChange.fire(this)}}const s={format:{tabSize:4,insertSpaces:!1,wrapLineLength:120,unformatted:'default": "a, abbr, acronym, b, bdo, big, br, button, cite, code, dfn, em, i, img, input, kbd, label, map, object, q, samp, select, small, span, strong, sub, sup, textarea, tt, var',contentUnformatted:"pre",indentInnerHtml:!1,preserveNewLines:!0,maxPreserveNewLines:void 0,indentHandlebars:!1,endWithNewline:!1,extraLiners:"head, body, /html",wrapAttributes:"auto"},suggest:{},data:{useDefaultDataProvider:!0}};function o(e){return{completionItems:!0,hovers:!0,documentSymbols:!0,links:!0,documentHighlights:!0,rename:!0,colors:!0,foldingRanges:!0,selectionRanges:!0,diagnostics:e===a,documentFormattingEdits:e===a,documentRangeFormattingEdits:e===a}}const a="html",m="handlebars",h="razor",g=r(a,s,o(a)),b=g.defaults,l=r(m,s,o(m)),L=l.defaults,d=r(h,s,o(h)),v=d.defaults;u.languages.html={htmlDefaults:b,razorDefaults:v,handlebarDefaults:L,htmlLanguageService:g,handlebarLanguageService:l,razorLanguageService:d,registerHTMLLanguageService:r};function S(){return new Promise((e,t)=>D(["../../htmlMode-DtjCNH-N"],e,t))}function r(e,t=s,c=o(e)){const i=new p(e,t,c);let f;const C=u.languages.onLanguage(e,async()=>{f=(await S()).setupMode(i)});return{defaults:i,dispose(){C.dispose(),f?.dispose(),f=void 0}}}n.handlebarDefaults=L,n.handlebarLanguageService=l,n.htmlDefaults=b,n.htmlLanguageService=g,n.razorDefaults=v,n.razorLanguageService=d,n.registerHTMLLanguageService=r,Object.defineProperty(n,Symbol.toStringTag,{value:"Module"})}));
