import{r as e}from"./react-DAXU6W__.js";import{g as t}from"./get-nonce-BYiZHLe3.js";var n=function(){var e=0,n=null;return{add:function(r){var o,u;0==e&&(n=function(){if(!document)return null;var e=document.createElement("style");e.type="text/css";var n=t();return n&&e.setAttribute("nonce",n),e}())&&(u=r,(o=n).styleSheet?o.styleSheet.cssText=u:o.appendChild(document.createTextNode(u)),function(e){(document.head||document.getElementsByTagName("head")[0]).appendChild(e)}(n)),e++},remove:function(){! --e&&n&&(n.parentNode&&n.parentNode.removeChild(n),n=null)}}},r=function(){var t,r=(t=n(),function(n,r){e.useEffect(function(){return t.add(n),function(){t.remove()}},[n&&r])});return function(e){var t=e.styles,n=e.dynamic;return r(t,n),null}};export{r as s};
