function t(t,n){return null==t||null==n?NaN:t<n?-1:t>n?1:t>=n?0:NaN}function n(t,n){return null==t||null==n?NaN:n<t?-1:n>t?1:n>=t?0:NaN}function r(r){let o,u,l;function f(t,n,r=0,e=t.length){if(r<e){if(0!==o(n,n))return e;do{const o=r+e>>>1;u(t[o],n)<0?r=o+1:e=o}while(r<e)}return r}return 2!==r.length?(o=t,u=(n,e)=>t(r(n),e),l=(t,n)=>r(t)-n):(o=r===t||r===n?r:e,u=r,l=r),{left:f,center:function(t,n,r=0,e=t.length){const o=f(t,n,r,e-1);return o>r&&l(t[o-1],n)>-l(t[o],n)?o-1:o},right:function(t,n,r=0,e=t.length){if(r<e){if(0!==o(n,n))return e;do{const o=r+e>>>1;u(t[o],n)<=0?r=o+1:e=o}while(r<e)}return r}}}function e(){return 0}const o=r(t).right;r(function(t){return null===t?NaN:+t}).center;const u=Math.sqrt(50),l=Math.sqrt(10),f=Math.sqrt(2);function i(t,n,r){const e=(n-t)/Math.max(0,r),o=Math.floor(Math.log10(e)),a=e/Math.pow(10,o),c=a>=u?10:a>=l?5:a>=f?2:1;let s,h,M;return o<0?(M=Math.pow(10,-o)/c,s=Math.round(t*M),h=Math.round(n*M),s/M<t&&++s,h/M>n&&--h,M=-M):(M=Math.pow(10,o)*c,s=Math.round(t/M),h=Math.round(n/M),s*M<t&&++s,h*M>n&&--h),h<s&&.5<=r&&r<2?i(t,n,2*r):[s,h,M]}function a(t,n,r){if(!((r=+r)>0))return[];if((t=+t)===(n=+n))return[t];const e=n<t,[o,u,l]=e?i(n,t,r):i(t,n,r);if(!(u>=o))return[];const f=u-o+1,a=new Array(f);if(e)if(l<0)for(let i=0;i<f;++i)a[i]=(u-i)/-l;else for(let i=0;i<f;++i)a[i]=(u-i)*l;else if(l<0)for(let i=0;i<f;++i)a[i]=(o+i)/-l;else for(let i=0;i<f;++i)a[i]=(o+i)*l;return a}function c(t,n,r){return i(t=+t,n=+n,r=+r)[2]}function s(t,n,r){r=+r;const e=(n=+n)<(t=+t),o=e?c(n,t,r):c(t,n,r);return(e?-1:1)*(o<0?1/-o:o)}function h(t,n){let r;if(void 0===n)for(const e of t)null!=e&&(r<e||void 0===r&&e>=e)&&(r=e);else{let e=-1;for(let o of t)null!=(o=n(o,++e,t))&&(r<o||void 0===r&&o>=o)&&(r=o)}return r}function M(t,n){let r;if(void 0===n)for(const e of t)null!=e&&(r>e||void 0===r&&e>=e)&&(r=e);else{let e=-1;for(let o of t)null!=(o=n(o,++e,t))&&(r>o||void 0===r&&o>=o)&&(r=o)}return r}function d(t,n,r){t=+t,n=+n,r=(o=arguments.length)<2?(n=t,t=0,1):o<3?1:+r;for(var e=-1,o=0|Math.max(0,Math.ceil((n-t)/r)),u=new Array(o);++e<o;)u[e]=t+e*r;return u}export{a,o as b,c,r as d,h as e,M as m,d as r,s as t};
