function n(n){for(var r=[],t=1;t<arguments.length;t++)r[t-1]=arguments[t];var a=Array.from("string"==typeof n?[n]:n);a[a.length-1]=a[a.length-1].replace(/\r?\n([\t ]*)$/,"");var e=a.reduce(function(n,r){var t=r.match(/\n([\t ]+|(?!\s).)/g);return t?n.concat(t.map(function(n){var r,t;return null!==(t=null===(r=n.match(/[\t ]/g))||void 0===r?void 0:r.length)&&void 0!==t?t:0})):n},[]);if(e.length){var c=new RegExp("\n[\t ]{"+Math.min.apply(Math,e)+"}","g");a=a.map(function(n){return n.replace(c,"\n")})}a[0]=a[0].replace(/^\r?\n/,"");var i=a[0];return r.forEach(function(n,r){var t=i.match(/(?:^|\n)( *)$/),e=t?t[1]:"",c=n;"string"==typeof n&&n.includes("\n")&&(c=String(n).split("\n").map(function(n,r){return 0===r?n:""+e+n}).join("\n")),i+=c+a[r+1]}),i}export{n as d};
