# SPDX-License-Identifier: Apache-2.0.
# Copyright (c) 2024 - 2025 Waldiez and contributors.
"""Version information for waldiez_studio.

Dev:
    Do not edit this file.
    Use ../package.json to update the version instead.
    The built package version will be set automatically by Hatchling.
    See ../scripts/hooks/metadata.py for more information.
"""

__version__ = "0.6.1"
