import{c as l}from"./clsx-BeLtu-UY.js";const e=l=>"boolean"==typeof l?`${l}`:0===l?"0":l,n=l,r=(l,r)=>s=>{var t;if(null==(null==r?void 0:r.variants))return n(l,null==s?void 0:s.class,null==s?void 0:s.className);const{variants:a,defaultVariants:u}=r,o=Object.keys(a).map(l=>{const n=null==s?void 0:s[l],r=null==u?void 0:u[l];if(null===n)return null;const t=e(n)||e(r);return a[l][t]}),i=s&&Object.entries(s).reduce((l,e)=>{let[n,r]=e;return void 0===r||(l[n]=r),l},{}),c=null==r||null===(t=r.compoundVariants)||void 0===t?void 0:t.reduce((l,e)=>{let{class:n,className:r,...s}=e;return Object.entries(s).every(l=>{let[e,n]=l;return Array.isArray(n)?n.includes({...u,...i}[e]):{...u,...i}[e]===n})?[...l,n,r]:l},[]);return n(l,o,c,null==s?void 0:s.class,null==s?void 0:s.className)};export{r as c};
